@@ -3,13 +3,15 @@ MapEntity.TogglableFilter = L.Class.extend({
     options: {},
 
     initialize: function () {
-        this.button = '#filters-btn';
+        var self = this;
+
+        this.$button = $('#filters-btn');
 
         this.fields = {};
         this.visible = false;
         this.popover = $('#filters-popover')
                           .popover({
-                              placement: 'bottom',
+                              placement: 'right',
                               html: true,
                               content: '',
                               title: 'Useless'
@@ -22,26 +24,20 @@ MapEntity.TogglableFilter = L.Class.extend({
                               title: tr("Current criteria")
                           });
 
-        $(this.button).click(this.toggle.bind(this));
-        $(this.button).mouseenter(this.showinfo.bind(this));
-        $(this.button).mouseleave(this.hideinfo.bind(this));
-        var self = this;
+        this.$button.mouseenter(this.showinfo.bind(this));
+        this.$button.mouseleave(this.hideinfo.bind(this));
+
         $('#mainfilter').find('select,input').change(function (e) {
             self.setfield(this);
         });
 
-        // Move all topology-filters to separate tab
-        $('#mainfilter .topology-filter').parent('p')
-                                         .detach().appendTo('#mainfilter > .right');
-
         // Use chosen for multiple values
-        // Remove empty value (set with empty_label in Django for all choice fields)
-        $('#mainfilter select[multiple] option:first-child').remove();
         $("form#mainfilter").bind("reset", function() {
             setTimeout(function() {
-                $('form#mainfilter select[multiple]').trigger('liszt:updated');
+                $('form#mainfilter select[multiple]').trigger('chosen:updated');
             }, 1);
         });
+
         // Make sure filter-set class is added if a choice is selected.
         $('#mainfilter select[multiple]').chosen().on('change', function (e) {
             var $target = $(e.target),
@@ -54,26 +50,41 @@ MapEntity.TogglableFilter = L.Class.extend({
                 $container.removeClass('filter-set');
             }
         });
-        // Filters close
-        $('#filters-close').click(this.toggle.bind(this));
+
+
+        //
+        // Filters open/close
+        //
+
+        // Close button
+        var toggle_func = this.toggle.bind(this);
+        $('#filters-close').click(toggle_func);
+
+
+        this.$button.click(function (e) {
+            e.stopPropagation();
+
+            // Open/Close from button
+            self.toggle();
+
+            // Close when click outside
+            if (self.visible) {
+                $(document).on('click.outside', function close_panel(e) {
+                    if (self.tip().has(e.target).length === 0 &&
+                        self.$button.has(e.target).length === 0) {
+                        self.toggle();
+                    }
+                });
+
+                self.popover.on('hidden.bs.popover', function () {
+                    $(document).off('click.outside');
+                });
+            }
+        });
     },
 
     tip: function () {
-        return this.popover.data('popover').$tip;
-    },
-
-    htip: function () {
-        return this.hover.data('popover').$tip;
-    },
-
-    __reposition: function (tip) {
-        // Adjust position nicely along filter button
-        var btnleft = $(this.button).position().left,
-            btnwidth = $(this.button).width(),
-            btntop = $(this.button).position().top,
-            btnheight = $(this.button).height();
-        tip.css('left', btnleft + btnwidth/2 - tip.width()/2);
-        tip.css('top', btntop + btnheight + 10);
+        return $(this.popover.data('bs.popover').tip);
     },
 
     showinfo: function () {
@@ -81,10 +92,6 @@ MapEntity.TogglableFilter = L.Class.extend({
         if (this.visible)
             return;
         this.hover.popover('show');
-        // Adjust popover width
-        this.htip()
-            .width(this.htip().find('.popover-title').outerWidth());
-        this.__reposition(this.htip());
     },
 
     hideinfo: function () {
@@ -99,7 +106,13 @@ MapEntity.TogglableFilter = L.Class.extend({
         var i = '';
         for (var k in this.fields) {
             var f = this.fields[k];
-            i += p.replace('%name%', f.label).replace('%value%', f.value);
+            var value = f.value;
+            value = value.replace(/&/g, '&amp;');
+            value = value.replace(/</g, '&lt;');
+            value = value.replace(/>/g, '&gt;');
+            value = value.replace(/">"/g, '&quot;');
+            value = value.replace(/'>'/g, '&#x27;');
+            i += p.replace('%name%', f.label).replace('%value%', value);
         }
         return i;
     },
@@ -127,8 +140,6 @@ MapEntity.TogglableFilter = L.Class.extend({
             // Adjust popover width
             this.tip()
                 .width(this.tip().find('#filters-panel form').outerWidth());
-
-            this.__reposition(this.tip());
         }
     },
 
@@ -152,9 +163,10 @@ MapEntity.TogglableFilter = L.Class.extend({
         // Displayed value
         var value = val;
         if (field.tagName == 'SELECT') {
-            value = $(field).find("option:selected").text();
+            value = $(field).find("option:selected").toArray().map(function (node) {
+                return $(node).text()
+            }).join(', ')
         }
-
         if (set) {
             this.fields[name] = {name: name, val:val, value:value, label:label};
         }
